# Release v$VERSION

## Release Notes

$CHANGELOG

## Installation

We recommend [uv package manager](https://github.com/astral-sh/uv)

```bash
uv add zeolite
```

## Documentation

For full documentation, visit [zeolite.dev](https://zeolite.dev) 